@@ -47,7 +47,7 @@ if __name__ != "__main__":
 		def get_file(self, file_name):
 			file_path = f"{self.path}\\{file_name}"
 			if not os.path.isfile(file_path):
-				raise errors.AbsentFileError
+				return None
 			return filePath(self.parts, file_path, file_name)
 
 		def is_subdir(self, path: object):
